netapp_ontap.models.s3_bucket_policy_condition API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.s3_bucket_policy_condition`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class S3BucketPolicyConditionSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the S3BucketPolicyCondition object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `delimiters GET POST PATCH`

    An array of delimiters that are compared with the delimiter value specified at the time of execution of an S3-based command, using the condition operator specified.

    Example: ["/"]

  `max_keys GET POST PATCH`

    An array of maximum keys that are allowed or denied to be retrieved using an S3 list operation, based on the condition operator specified.

    Example: [1000]

  `operator GET POST PATCH`

    Condition operator that is applied to the specified condition key.

    Valid choices:

    - ip_address
    - not_ip_address
    - string_equals
    - string_not_equals
    - string_equals_ignore_case
    - string_not_equals_ignore_case
    - string_like
    - string_not_like
    - numeric_equals
    - numeric_not_equals
    - numeric_greater_than
    - numeric_greater_than_equals
    - numeric_less_than
    - numeric_less_than_equals
  `prefixes GET POST PATCH`

    An array of prefixes that are compared with the input prefix value specified at the time of execution of an S3-based command, using the condition operator specified.

    Example: ["pref"]

  `source_ips GET POST PATCH`

    An array of IP address ranges that are compared with the IP address of a source command at the time of execution of an S3-based command, using the condition operator specified.

    Example: ["1.1.1.1","1.2.2.0/24"]

  `usernames GET POST PATCH`

    An array of usernames that a current user in the context is evaluated against using the condition operators.

    Example: ["user1"]